import React, { useState } from 'react';
import { motion } from 'framer-motion';

var Text = function Text(_ref) {
  var children = _ref.children,
      _ref$as = _ref.as,
      as = _ref$as === void 0 ? "p" : _ref$as,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 14 : _ref$size,
      _ref$lineHeight = _ref.lineHeight,
      lineHeight = _ref$lineHeight === void 0 ? "normal" : _ref$lineHeight,
      weight = _ref.weight,
      transform = _ref.transform,
      align = _ref.align,
      color = _ref.color,
      className = _ref.className,
      style = _ref.style;
  var classes = [];
  className && classes.push(className);

  switch (size) {
    case 10:
      classes.push("text-10");
      break;

    case 12:
      classes.push("text-12");
      break;

    case 14:
      classes.push("text-14");
      break;

    case 16:
      classes.push("text-16");
      break;

    case 20:
      classes.push("text-20");
      break;

    case 24:
      classes.push("text-24");
      break;

    case 32:
      classes.push("text-32");
      break;

    case 40:
      classes.push("text-40");
      break;

    case 10:
      classes.push("text-48");
  }

  switch (lineHeight) {
    case 12:
      classes.push("leading-12");
      break;

    case 16:
      classes.push("leading-16");
      break;

    case 20:
      classes.push("leading-20");
      break;

    case 24:
      classes.push("leading-24");
      break;

    case 32:
      classes.push("leading-32");
      break;

    case 40:
      classes.push("leading-40");
      break;

    case 48:
      classes.push("leading-48");
      break;

    case 56:
      classes.push("leading-56");
      break;

    default:
      classes.push("normal");
  }

  switch (weight) {
    case 100:
      classes.push("font-thin");
      break;

    case 200:
      classes.push("font-extralight");
      break;

    case 300:
      classes.push("font-light");
      break;

    case 400:
      classes.push("font-normal");
      break;

    case 500:
      classes.push("font-medium");
      break;

    case 600:
      classes.push("font-semibold");
      break;

    case 700:
      classes.push("font-bold");
      break;

    case 800:
      classes.push("font-extrabold");
      break;

    case 900:
      classes.push("font-black");
  }

  switch (transform) {
    case "capitalize":
      classes.push("capitalize");
      break;

    case "uppercase":
      classes.push("uppercase");
      break;

    case "lowercase":
      classes.push("lowercase");
  }

  switch (align) {
    case "left":
      classes.push("text-left");
      break;

    case "center":
      classes.push("text-center");
      break;

    case "right":
      classes.push("text-right");
  }

  switch (color) {
    case "black":
      classes.push("text-black");
      break;

    case "gray-50":
      classes.push("text-gray-50");
      break;

    case "gray-100":
      classes.push("text-gray-100");
      break;

    case "gray-200":
      classes.push("text-gray-200");
      break;

    case "gray-300":
      classes.push("text-gray-300");
      break;

    case "gray-400":
      classes.push("text-gray-400");
      break;

    case "gray-500":
      classes.push("text-gray-500");
      break;

    case "gray-600":
      classes.push("text-gray-600");
      break;

    case "gray-700":
      classes.push("text-gray-700");
      break;

    case "gray-800":
      classes.push("text-gray-800");
      break;

    case "gray-900":
      classes.push("text-gray-900");
      break;
  }

  return React.createElement(as, {
    className: classes.join(" "),
    style: style
  }, children);
};

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

/*
  Clickable items animations
*/
var clickable = {
  hover: {
    filter: "brightness(1.4)",
    transition: {
      duration: 0
    }
  },
  tap: {
    filter: "brightness(1.3)",
    transition: {
      duration: 0
    }
  }
};
var clickableWithScale = {
  hover: /*#__PURE__*/_extends({}, clickable.hover),
  tap: /*#__PURE__*/_extends({}, clickable.tap, {
    scale: 1.04
  })
};

var Button = function Button(_ref) {
  var children = _ref.children,
      icon = _ref.icon,
      onClick = _ref.onClick,
      className = _ref.className,
      _ref$as = _ref.as,
      as = _ref$as === void 0 ? "button" : _ref$as,
      type = _ref.type,
      href = _ref.href,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? "base" : _ref$size,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? "gray" : _ref$color,
      prefix = _ref.prefix,
      suffix = _ref.suffix;
  var classes = ["flex items-center justify-center pointer-events-auto rounded-lg leading-none focus:outline-none shadow-button w-min whitespace-nowrap"];

  switch (size) {
    case "sm":
      classes.push("p-2 text-14 rounded-md");
      break;

    case "base":
      classes.push("p-3 rounded-lg");
      break;

    case "lg":
      classes.push("p-4 rounded-lg");
      break;
  }

  switch (color) {
    case "gray":
      classes.push("text-gray-300 bg-gray-800");
      break;

    case "blue":
      classes.push("text-blue-50 bg-blue-800");
      break;

    case "green":
      classes.push("text-green-50 bg-green-800");
      break;

    case "rose":
      classes.push("text-rose-50 bg-rose-800");
      break;

    case "amber":
      classes.push("text-amber-50 bg-amber-800");
      break;
  }

  className && classes.push(className);
  return as === "button" ? React.createElement(motion.button, {
    whileHover: clickable.hover,
    whileTap: clickable.tap,
    className: classes.join(" "),
    onClick: onClick,
    type: type
  }, prefix && React.createElement("span", {
    className: "w-5 h-5 mr-2"
  }, prefix), icon && React.createElement("span", {
    className: "w-5 h-5"
  }, icon), children && React.createElement("span", null, children), suffix && React.createElement("span", {
    className: "w-5 h-5 ml-2"
  }, suffix)) : React.createElement(motion.a, {
    href: href,
    whileHover: clickable.hover,
    whileTap: clickable.tap,
    className: classes.join(" "),
    onClick: onClick,
    type: type
  }, prefix && React.createElement("span", {
    className: "w-5 h-5 mr-2"
  }, prefix), icon && React.createElement("span", {
    className: "w-5 h-5"
  }, icon), children, suffix && React.createElement("span", {
    className: "w-5 h-5 ml-2"
  }, suffix));
};

var IconSearch = function IconSearch(props) {
  return React.createElement("svg", Object.assign({
    xmlns: "http://www.w3.org/2000/svg",
    fill: "none",
    viewBox: "0 0 24 24",
    stroke: "currentColor"
  }, props), React.createElement("path", {
    strokeLinecap: "round",
    strokeLinejoin: "round",
    strokeWidth: 2,
    d: "M21 21l-6-6m2-5a7 7 0 11-14 0 7 7 0 0114 0z"
  }));
};
var IconCross = function IconCross(props) {
  return React.createElement("svg", Object.assign({
    xmlns: "http://www.w3.org/2000/svg",
    fill: "none",
    viewBox: "0 0 24 24",
    stroke: "currentColor"
  }, props), React.createElement("path", {
    strokeLinecap: "round",
    strokeLinejoin: "round",
    strokeWidth: 2,
    d: "M6 18L18 6M6 6l12 12"
  }));
};

var Input = /*#__PURE__*/React.memo(function (_ref) {
  var prefix = _ref.prefix,
      placeholder = _ref.placeholder,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? "text" : _ref$type,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? "gray" : _ref$color,
      _onChange = _ref.onChange,
      _ref$withCross = _ref.withCross,
      withCross = _ref$withCross === void 0 ? false : _ref$withCross,
      defaultValue = _ref.defaultValue,
      id = _ref.id,
      _ref$shadow = _ref.shadow,
      shadow = _ref$shadow === void 0 ? false : _ref$shadow,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      className = _ref.className;

  var _useState = useState(function () {
    return defaultValue ? defaultValue : "";
  }),
      value = _useState[0],
      setValue = _useState[1];

  var _useState2 = useState(function () {
    return value.length > 0 ? true : false;
  }),
      showX = _useState2[0],
      setShowX = _useState2[1];

  var containerClasses = ["flex items-center justify-start w-64 p-2 px-2 rounded-lg pointer-events-auto focus:outline-none"];
  var inputClasses = ["w-full h-full bg-transparent focus:outline-none"];

  switch (color) {
    case "gray":
      inputClasses.push("placeholder-gray-300");
      containerClasses.push("bg-gray-800 text-gray-200");
      break;

    case "blue":
      inputClasses.push("placeholder-blue-300");
      containerClasses.push("bg-blue-900 text-blue-200");
      break;

    case "green":
      inputClasses.push("placeholder-green-300");
      containerClasses.push("bg-green-900 text-green-200");
      break;

    case "rose":
      inputClasses.push("placeholder-rose-300");
      containerClasses.push("bg-rose-900 text-rose-200");
      break;

    case "amber":
      inputClasses.push("placeholder-amber-300");
      containerClasses.push("bg-amber-900 text-amber-200");
      break;
  }

  className && containerClasses.push(className);
  shadow && containerClasses.push("shadow-button");
  disabled && containerClasses.push("cursor-not-allowed bg-opacity-60");
  disabled && inputClasses.push("cursor-not-allowed");
  return React.createElement(motion.div, {
    whileHover: disabled ? "" : clickable.hover,
    className: containerClasses.join(" ")
  }, prefix && React.createElement("span", {
    className: "flex-shrink-0 w-5 h-5 mr-2"
  }, prefix), React.createElement("input", {
    id: id,
    type: type,
    value: value,
    disabled: disabled,
    placeholder: placeholder,
    className: inputClasses.join(" "),
    onChange: function onChange(e) {
      setValue(e.target.value);
      setShowX(e.target.value.length > 0 ? true : false);
      console.log("log on change");
      _onChange && _onChange(e);
    }
  }), withCross && showX && React.createElement("button", {
    className: "flex-shrink-0 w-5 h-5 ml-2",
    onClick: function onClick() {
      setValue("");
      setShowX(false);
    }
  }, React.createElement(IconCross, null)));
});

var _require = /*#__PURE__*/require("tailwindcss/defaultTheme"),
    fontFamily = _require.fontFamily;
var tailwindPreset = {
  theme: {
    fontFamily: {
      sans: /*#__PURE__*/["Inter"].concat(fontFamily.sans),
      chakra: /*#__PURE__*/["Chakra Petch"].concat(fontFamily.mono)
    },
    fontSize: {
      10: "0.625rem",
      12: "0.75rem",
      14: "0.875rem",
      16: "1rem",
      20: "1.25rem",
      24: "1.5rem",
      32: "2rem",
      40: "2.5rem",
      48: "3rem"
    },
    lineHeight: {
      none: 1,
      base: "1.5",
      12: "0.75rem",
      16: "1rem",
      20: "1.25rem",
      24: "1.5rem",
      32: "2rem",
      40: "2.5rem",
      48: "3rem",
      56: "3.5rem"
    },
    colors: {
      transparent: "transparent",
      current: "currentColor",
      black: "#000",
      white: "#fff",
      gray: {
        50: "#fafafa",
        100: "#f5f5f5",
        200: "#e5e5e5",
        300: "#d4d4d4",
        400: "#a3a3a3",
        500: "#737373",
        600: "#525252",
        700: "#404040",
        800: "#262626",
        900: "#171717"
      },
      rose: {
        50: "#fff1f2",
        100: "#ffe4e6",
        200: "#fecdd3",
        300: "#fda4af",
        400: "#fb7185",
        500: "#f43f5e",
        600: "#e11d48",
        700: "#be123c",
        800: "#9f1239",
        900: "#881337"
      },
      amber: {
        50: "#fffbeb",
        100: "#fef3c7",
        200: "#fde68a",
        300: "#fcd34d",
        400: "#fbbf24",
        500: "#f59e0b",
        600: "#d97706",
        700: "#b45309",
        800: "#92400e",
        900: "#78350f"
      },
      blue: {
        50: "#eff6ff",
        100: "#dbeafe",
        200: "#bfdbfe",
        300: "#93c5fd",
        400: "#60a5fa",
        500: "#3b82f6",
        600: "#2563eb",
        700: "#1d4ed8",
        800: "#1e40af",
        900: "#1e3a8a"
      },
      green: {
        50: "#f0fdf4",
        100: "#dcfce7",
        200: "#bbf7d0",
        300: "#86efac",
        400: "#4ade80",
        500: "#22c55e",
        600: "#16a34a",
        700: "#15803d",
        800: "#166534",
        900: "#14532d"
      }
    },
    boxShadow: {
      header: "0 3px 10px 0 rgba(0, 0, 0, 0.2)",
      button: "0 3px 6px 0 rgba(0, 0, 0, 0.1)"
    }
  },
  plugins: [/*#__PURE__*/require("@tailwindcss/line-clamp"), /*#__PURE__*/require("@tailwindcss/aspect-ratio")]
};

export { Button, IconCross, IconSearch, Input, Text, clickable, clickableWithScale, tailwindPreset };
//# sourceMappingURL=penthouse-design.esm.js.map
